Module input

Module input 

This module contains structures and methods for specifying parameters of the analysis.

Re-exports

pub use analysis::Analysis;
pub use analysis::AnalysisType;
pub use axis::Axis;
pub use estimate_error::EstimateError;
pub use frequency::Frequency;
pub use geometry::GeomReference;
pub use geometry::Geometry;
pub use leaflets::LeafletClassification;
pub use membrane_normal::DynamicNormal;
pub use membrane_normal::MembraneNormal;
pub use ordermap::GridSpan;
pub use ordermap::OrderMap;
pub use ordermap::Plane;

Modules

analysis
Contains the implementation of the main Analysis structure and its methods.
axis
Contains the implementation of the Axis structure and its methods.
estimate_error
Contains the implementation of the EstimateError structure and its methods.
frequency
geometry
Contains the implementation of the Geometry structure and its methods.
leaflets
Contains structures and methods for the assignment of lipids into membrane leaflets.
membrane_normal
This module contains structures and methods for specifying membrane normal.
ordermap
Contains structures and methods for the construction of maps of order parameters.

Enums

Collect
Helper struct specifying whether some data should be collected or not and where they should be exported to.