pub struct SphereSelection { /* private fields */ }Expand description
Represents a sphere used to select bonds located within its bounds.
Implementations
Sourceimpl SphereSelection
impl SphereSelection
Sourcepub fn reference(&self) -> &GeomReference
pub fn reference(&self) -> &GeomReference
The reference point corresponding to the center of the sphere. This can be an absolute position or a selection of atoms whose center of geometry defines the reference point. Defaults to [0, 0, 0] (the origin of the coordinate system) if not specified.