pub struct OrderMap { /* private fields */ }Expand description
Parameters for constructing ordermaps.
Implementations
Sourceimpl OrderMap
impl OrderMap
Sourcepub fn output_directory(&self) -> &Option<String>
pub fn output_directory(&self) -> &Option<String>
Directory where the output files containing the individual ordermaps will be saved.
Sourceimpl OrderMap
impl OrderMap
Sourcepub fn min_samples(&self) -> usize
pub fn min_samples(&self) -> usize
Minimum number of samples required in a grid tile to calculate the order parameter. The default value is 1.
Sourcepub fn dim(&self) -> [GridSpan; 2]
pub fn dim(&self) -> [GridSpan; 2]
Span of the grid along the axes. The first span corresponds to the x-axis (if the map is in the xy or xz plane) or the z-axis (if the map is in the yz plane). The second span corresponds to the y-axis (if the map is in the xy or yz plane) or the z-axis (if the map is in the xz plane). If not specified, the span is derived from the simulation box size of the input structure.
Sourcepub fn bin_size(&self) -> [f32; 2]
pub fn bin_size(&self) -> [f32; 2]
Size of the grid bin along the axes. The first bin dimension corresponds to the x-axis (if the map is in the xy or xz plane) or the z-axis (if the map is in the yz plane). The second bin dimension corresponds to the y-axis (if the map is in the xy or yz plane) or the z-axis (if the map is in the xz plane). The default value is 0.1 x 0.1 nm if not specified.